django-memoize
==============

.. image:: https://travis-ci.org/tvavrys/django-memoize.svg?branch=master
    :target: https://travis-ci.org/tvavrys/django-memoize
.. image:: https://badge.fury.io/py/django-memoize.svg
    :target: http://badge.fury.io/py/django-memoize
.. image:: https://coveralls.io/repos/github/tvavrys/django-memoize/badge.svg?branch=master
    :target: https://coveralls.io/github/tvavrys/django-memoize?branch=master
|
**django-memoize** is an implementation
of `memoization <http://en.wikipedia.org/wiki/Memoization>`_ technique
for Django. You can think of it as a cache for function or method results.


Documentation
-------------

Documentation is available at http://django-memoize.readthedocs.io/en/latest/.

Requirements
------------

Latest supported Django versions. See `tox.ini`.
